"""
OncoTree_get_type

Get detailed information about a specific OncoTree cancer type by its exact code (e.g. 'BRCA', 'L...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def OncoTree_get_type(
    code: str,
    version: Optional[str] = "oncotree_latest_stable",
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get detailed information about a specific OncoTree cancer type by its exact code (e.g. 'BRCA', 'L...

    Parameters
    ----------
    code : str
        OncoTree cancer type code (case-insensitive). Examples: 'BRCA' (Invasive Brea...
    version : str
        OncoTree version. Default: 'oncotree_latest_stable'.
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v for k, v in {"code": code, "version": version}.items() if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "OncoTree_get_type",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["OncoTree_get_type"]
